"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
let conn;
class create extends command_1.SfdxCommand {
    async run() {
        conn = await this.org.getConnection();
        this.ux.startSpinner("Creating NamedCredential");
        let namedCredentials = new Array();
        namedCredentials.push({ fullName: this.flags.name,
            label: this.flags.name,
            endpoint: this.flags.url,
            generateAuthorizationHeader: true,
            allowMergeFieldsInBody: false,
            allowMergeFieldsInHeader: false,
            principalType: 'Anonymous',
            protocol: 'NoAuthentication'
        });
        await conn.metadata.create('NamedCredential', namedCredentials)
            .then(result => {
            let untypeResult = result;
            if (untypeResult.success) {
                this.ux.stopSpinner("Successfully created NamedCredential");
            }
            else {
                this.ux.stopSpinner(untypeResult.errors.message);
            }
        });
        return true;
    }
}
create.description = 'Create a named credential for an url';
create.requiresUsername = true;
// Comment this out if your command does not support a hub org username
create.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
create.requiresProject = true;
create.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    name: command_1.flags.string({ char: 'n', description: 'Name of the named credential ', required: true }),
    url: command_1.flags.string({ description: 'Url to apply things', required: true })
};
exports.default = create;
//# sourceMappingURL=create.js.map