"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const child = require("child_process");
const util = require("util");
const fs = require("fs");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class Export extends command_1.SfdxCommand {
    async run() {
        if (fs.existsSync('data')) {
            await fs.readdirSync('data').forEach(file => {
                console.log(file);
                fs.unlinkSync('data/' + file);
            });
        }
        const exec = util.promisify(child.exec);
        const objects = this.flags.objects.split(',');
        let allRecordsMap = new Map();
        let objectsJson = [];
        for (const object of objects) {
            const exist = await this.checkIfAllreadyExist(object);
            if (!exist) {
                let allfields = [];
                let allLookup = [];
                const result = await (await JSON.parse(await (await exec('sfdx force:schema:sobject:describe -s ' + object + ' --json')).stdout).result);
                for (const field of result.fields) {
                    if (field.createable && field.name != "OwnerId" && field.name != "CreatedById" && field.name != "LastModifiedById") {
                        allfields.push(field.name);
                        if (field.referenceTo && field.referenceTo.length > 0) {
                            if (field.custom && field.referenceTo.includes('User')) {
                                allLookup.push(field.name);
                            }
                            else if (!field.referenceTo.includes('User')) {
                                allLookup.push(field.name);
                            }
                        }
                    }
                }
                let query = '"Select Id ,' + allfields.join() + ' from ' + object + '"';
                const resultSoql = await (await JSON.parse(await (await exec('sfdx force:data:soql:query -q ' + query + ' --json ')).stdout).result);
                resultSoql["lookups"] = allLookup;
                var compteur = 1;
                for (let record of resultSoql.records) {
                    const reference = "@RefObject@" + object + "@EndRefObject@" + compteur;
                    record.attributes["referenceId"] = reference;
                    delete record.attributes["url"];
                    allRecordsMap.set(record.Id, reference);
                    compteur = compteur + 1;
                    for (let field of allfields) {
                        if (!record[field])
                            delete record[field];
                    }
                }
                objectsJson.push(resultSoql);
            }
        }
        for (let object of objectsJson) {
            for (let record of object.records) {
                for (let lookup of object.lookups) {
                    if (record[lookup]) {
                        record[lookup] = allRecordsMap.get(record[lookup]);
                    }
                }
                delete record.Id;
            }
            delete object.totalSize;
            delete object.done;
            if (!fs.existsSync('data')) {
                await fs.mkdirSync('data');
            }
            await fs.writeFileSync('data/' + object.records[0].attributes.type + '.json', JSON.stringify(object, null, 4));
        }
        return true;
    }
    async checkIfAllreadyExist(sobject) {
        if (fs.existsSync('data/' + sobject + 's.json')) {
            return true;
        }
        else {
            return false;
        }
    }
}
Export.description = '(Bêta) Export data from current org.';
Export.args = [{ name: 'file' }];
Export.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Export.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Export.requiresProject = true;
Export.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    objects: command_1.flags.string({ char: 'o', description: 'Objets Names to be retrieved', required: true }),
};
exports.default = Export;
//# sourceMappingURL=export.js.map