"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const util = require("util");
const child = require("child_process");
const fs = require("fs");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class Export extends command_1.SfdxCommand {
    async run() {
        const exec = util.promisify(child.exec);
        this.createSfdxProjectData();
        this.ux.startSpinner(`Setting default username to ${this.flags.targetuser}`);
        await exec(`sfdx config:set defaultusername=${this.flags.targetuser}`);
        this.ux.stopSpinner();
        this.ux.startSpinner(`Getting flows`);
        const execRetrieve = this.flags.filenames ? `sfdx force:source:retrieve -m "${this.flags.filenames.split(',').map(x => "Flow : " + x)}" ` : 'sfdx force:source:retrieve -m Flow';
        await exec(execRetrieve);
        this.ux.stopSpinner();
        return true;
    }
    createSfdxProjectData() {
        const data = {
            "packageDirectories": [
                {
                    "path": "force-app",
                    "default": true
                }
            ],
            "namespace": "gnx",
            "sfdcLoginUrl": "https://login.salesforce.com",
            "sourceApiVersion": "52.0"
        };
        fs.writeFileSync('sfdx-project.json', JSON.stringify(data));
        if (!fs.existsSync("force-app")) {
            fs.mkdirSync("force-app");
        }
    }
}
Export.description = 'Export flows from org';
Export.args = [{ name: 'file' }];
Export.requiresUsername = false;
// Comment this out if your command does not support a hub org username
Export.supportsDevhubUsername = false;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Export.requiresProject = false;
Export.flagsConfig = {
    targetuser: command_1.flags.string({ char: 't', description: 'Objets Names to be retrieved', required: true }),
    filenames: command_1.flags.string({ char: 'f', description: 'Files names to be retrieved', required: false })
};
exports.default = Export;
//# sourceMappingURL=export.js.map