"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const js_base64_1 = require("js-base64");
const fs = require("fs");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
let conn;
class insert extends command_1.SfdxCommand {
    async run() {
        this.ux.startSpinner("Inserting file");
        conn = await this.org.getConnection();
        const path_file = this.flags.path;
        const filename = path_file.substring(path_file.lastIndexOf('/') + 1);
        const fileBase64 = js_base64_1.Base64.encode(fs.readFileSync(path_file, { encoding: 'utf8' }));
        const objectRecords = new Array();
        objectRecords.push({ "ContentLocation": "S", "VersionData": fileBase64, "Title": filename, "PathOnClient": filename });
        await conn.sobject("ContentVersion").insert(objectRecords)
            .then(async (result) => {
            if (result[0].success) {
                let contentVersionid = result[0].id;
                this.ux.stopSpinner("The file has been successfully created with id : " + contentVersionid);
                let documentTemplateId = await this.createDocumentTemplate(this.flags.name);
                return this.createContentDocumentLink(documentTemplateId, contentVersionid);
            }
            else {
                this.ux.stopSpinner("Error when creating the file");
                console.log(result[0]);
            }
        });
        return false;
    }
    async createDocumentTemplate(name) {
        this.ux.startSpinner("Inserting document template");
        let documentTemplateId = null;
        const objectRecords = new Array();
        objectRecords.push({ "Name": name });
        await conn.sobject("gnx__Document_template__c").insert(objectRecords)
            .then(result => {
            if (result[0].success) {
                documentTemplateId = result[0].id;
                this.ux.stopSpinner("The document template has been successfully created with id : " + documentTemplateId);
            }
            else {
                this.ux.stopSpinner("Error when creating document template");
                console.log(result[0]);
            }
        });
        return documentTemplateId;
    }
    async createContentDocumentLink(documentTemplateId, contentVersionid) {
        this.ux.startSpinner("Inserting document template");
        let contentDocumentId = await conn.query('SELECT ContentDocumentId FROM ContentVersion WHERE Id = \'' + contentVersionid + '\'');
        const objectRecords = new Array();
        objectRecords.push({ "ContentDocumentId": contentDocumentId.records[0].ContentDocumentId,
            "LinkedEntityId": documentTemplateId,
            "ShareType": "I",
            "Visibility": "AllUsers" });
        await conn.sobject("ContentDocumentLink").insert(objectRecords).then(result => {
            if (result[0].success) {
                this.ux.stopSpinner("The link between the template and the file has been successfully created ");
                return true;
            }
            else {
                this.ux.stopSpinner("Error when linking document template and file");
                console.log(result[0]);
            }
        });
        return false;
    }
}
insert.description = 'Create a Exadoc Document Template with a file associated.';
insert.requiresUsername = true;
// Comment this out if your command does not support a hub org username
insert.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
insert.requiresProject = true;
insert.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    path: command_1.flags.string({ char: 'p', description: 'File path to be inserted', required: true }),
    name: command_1.flags.string({ char: 'n', description: 'Document template name', required: true }),
};
exports.default = insert;
//# sourceMappingURL=insert.js.map