"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const util = require("util");
const child = require("child_process");
const gonexadocVersions_1 = require("../../../scripts/gonexadocVersions");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class Install extends command_1.SfdxCommand {
    async run() {
        const exec = util.promisify(child.exec);
        const { id, number } = this.getVersion();
        const namePermisionSet = "ExaDoc_admin_permission_sets";
        this.ux.startSpinner(`Installation de la version ${number} d'Exadoc`);
        await exec('sfdx force:package:install -p ' + id + ' -w 10 -s AdminsOnly -r');
        this.ux.stopSpinner();
        this.ux.startSpinner("Attribution de l'ensemble de permissions");
        await exec('sfdx force:user:permset:assign -n ' + namePermisionSet);
        this.ux.stopSpinner();
        return true;
    }
    getVersion() {
        if (this.flags.number) {
            if (gonexadocVersions_1.default[this.flags.number])
                return { id: gonexadocVersions_1.default[this.flags.number], number: this.flags.number };
        }
        return { id: gonexadocVersions_1.default["1.23.1.1"], number: "1.23.1.1" };
    }
}
Install.description = 'Install last version of ExaDoc';
Install.args = [{ name: 'file' }];
Install.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Install.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Install.requiresProject = false;
Install.flagsConfig = {
    number: command_1.flags.string({ char: 'n', description: 'Gonexa Doc version', required: false })
};
exports.default = Install;
//# sourceMappingURL=install.js.map