"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const fs = require("fs");
var utility = require('../../../scripts/utility.ts');
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
async function getMap() {
    var mapToInsert = new Map();
    fs.readdirSync('manifest').forEach(async (file) => {
        var data = fs.readFileSync('manifest/' + file);
        utility.promisesParser(data).then(function (result) {
            var resultArray = Object.keys(result).map(function (index) {
                let array = result[index];
                return array;
            });
            if (resultArray.length > 0) {
                resultArray.forEach(function (item) {
                    if (item.types != undefined) {
                        item.types.forEach(function (type) {
                            if (!mapToInsert.has(type.name[0])) {
                                mapToInsert.set(type.name[0], type.members);
                            }
                            else {
                                var newValues = new Set();
                                var ancientValues = mapToInsert.get(type.name[0]);
                                if (ancientValues != undefined) {
                                    ancientValues.forEach(value => {
                                        newValues.add(value);
                                    });
                                }
                                if (type.members != undefined) {
                                    type.members.forEach(value => {
                                        newValues.add(value);
                                    });
                                }
                                mapToInsert.set(type.name[0], newValues);
                            }
                        });
                    }
                });
            }
        }).catch(function (err) {
            console.log(err);
        });
    });
    return mapToInsert;
}
class assemble extends command_1.SfdxCommand {
    async run() {
        fs.access('manifest', fs.constants.F_OK, async (err) => {
            if (err) {
                this.ux.log('Dossier manifest n\'existe pas.');
            }
            else {
                var mapToInsert = await getMap();
                var xml = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?> \n<Package xmlns="http://soap.sforce.com/2006/04/metadata">';
                mapToInsert.forEach((values, key) => {
                    xml = xml + '\n \t<types>';
                    values.forEach(function (value) {
                        xml = xml + '\n \t \t<members>' + value + '</members>';
                    });
                    xml = xml + '\n \t \t<name>' + key + '</name>';
                    xml = xml + '\n \t</types>';
                });
                xml = xml + '\n</Package>';
                fs.writeFile('manifest/package.xml', xml, (err) => {
                    if (err) {
                        throw err;
                    }
                    else {
                        this.ux.log('Package.xml à été créé');
                    }
                });
            }
        });
        return true;
    }
}
assemble.description = 'Assemble all xml files from manifest folder into package.xml';
exports.default = assemble;
//# sourceMappingURL=assemble.js.map