"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const fs = require("fs");
const util = require("../../../scripts/connexion");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
class classes extends command_1.SfdxCommand {
    async run() {
        fs.access('manifest', fs.constants.F_OK, async (err) => {
            if (err) {
                this.ux.log('Manifest folder doesn\'t exist. Create it before executing this command.');
                return false;
            }
            else {
                let xml;
                if (this.flags.fromproject) {
                    xml = await this.createFromProject();
                }
                else {
                    xml = await this.createFromOrg();
                }
                this.ux.startSpinner("Creating file");
                let name = (this.flags.name == null || this.flags.name == undefined) ? 'package.xml' : this.flags.name;
                await fs.writeFileSync('manifest/' + name, xml);
                this.ux.stopSpinner();
            }
        });
        return true;
    }
    async createFromOrg() {
        this.ux.startSpinner("Getting data");
        const conn = await this.org.getConnection();
        let fileStats = await fs.statSync(process.cwd());
        let xml = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?> \n <Package xmlns="http://soap.sforce.com/2006/04/metadata">';
        let query = 'Select Name from ApexClass where CreatedDate >= ' + fileStats.birthtime.toISOString();
        let resultApexClasses = await util.getXmlQuery(query, conn, 'ApexClass');
        if (resultApexClasses != null)
            xml = xml + '\n' + resultApexClasses;
        query = 'Select DeveloperName from AuraDefinitionBundle where CreatedDate >= ' + fileStats.birthtime.toISOString();
        let resultAuraDefinitionBundle = await util.getXmlQuery(query, conn, 'AuraDefinitionBundle');
        if (resultAuraDefinitionBundle != null)
            xml = xml + '\n' + resultAuraDefinitionBundle;
        query = 'Select Name from ApexTrigger where CreatedDate >= ' + fileStats.birthtime.toISOString();
        let resultApexTriggers = await util.getXmlQuery(query, conn, 'ApexTrigger');
        if (resultApexTriggers != null)
            xml = xml + '\n' + resultApexTriggers;
        xml = xml + '\n<version>48.0</version>\n</Package>';
        this.ux.stopSpinner();
        return xml;
    }
    async createFromProject() {
        this.ux.startSpinner("Getting data");
        let xml = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?> \n <Package xmlns="http://soap.sforce.com/2006/04/metadata">';
        let resultLwc = await util.getComponentsSource('./force-app/main/default/lwc', 'LightningComponentBundle');
        if (resultLwc != null)
            xml = xml + '\n' + resultLwc;
        let resultAura = await util.getComponentsSource('./force-app/main/default/aura', 'AuraDefinitionBundle');
        if (resultAura != null)
            xml = xml + '\n' + resultAura;
        let resultApexClasses = await util.getClassesSource('./force-app/main/default/classes', 'ApexClass');
        if (resultApexClasses != null)
            xml = xml + '\n' + resultApexClasses;
        let resultTriggers = await util.getClassesSource('./force-app/main/default/triggers', 'ApexTrigger');
        if (resultTriggers != null)
            xml = xml + '\n' + resultTriggers;
        xml = xml + '\n<version>48.0</version>\n</Package>';
        this.ux.stopSpinner();
        return xml;
    }
}
classes.description = 'Create an xml file with all developper stuff (classes , triggers , lwc , aura components) from the project or from the org (in regards to the created date).'
    + 'Default is from the org.';
classes.args = [{ name: 'file' }];
classes.requiresUsername = true;
// Comment this out if your command does not support a hub org username
classes.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
classes.requiresProject = true;
classes.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    name: command_1.flags.string({ char: 'n', description: ' File name to be created(default package.xml)' }),
    fromproject: command_1.flags.boolean({ char: 'p', description: 'create xml file from sources (vs code)' })
};
exports.default = classes;
//# sourceMappingURL=generate.js.map