"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const fs = require("fs");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class dashboard extends command_1.SfdxCommand {
    async run() {
        const conn = this.org.getConnection();
        let query = 'SELECT DeveloperName, FolderName FROM Dashboard where FolderName Like \'%' + this.flags.folder + '%\'';
        const result = await conn.query(query);
        if (!result.records || result.records.length <= 0) {
            this.ux.log("No data found");
        }
        else {
            fs.access('manifest', fs.constants.F_OK, (err) => {
                if (err) {
                    this.ux.log('Dossier manifeste créé car il n\'existait pas.');
                    fs.mkdirSync('manifest');
                }
            });
            let folders = new Set();
            for (var record of result.records) {
                folders.add(record.FolderName);
            }
            var xml = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?> \n <Package xmlns="http://soap.sforce.com/2006/04/metadata"> \n \t <types>';
            for (let folder of folders) {
                xml = xml + '\n \t \t<members>' + folder + '</members>';
            }
            for (var record of result.records) {
                xml = xml + '\n \t \t<members>' + record.FolderName + '/' + record.DeveloperName + '</members>';
            }
            xml = xml + '\n \t \t<name>Dashboard</name> \n \t</types>\n<version>48.O</version>\n</Package>';
            fs.writeFileSync('manifest/dashboards.xml', xml);
            console.log(result);
        }
        return true;
    }
}
dashboard.description = 'Create an xml file for a dashboard with folder name';
dashboard.args = [{ name: 'file' }];
dashboard.requiresUsername = true;
// Comment this out if your command does not support a hub org username
dashboard.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
dashboard.requiresProject = true;
dashboard.flagsConfig = {
    folder: command_1.flags.string({ char: 'f', description: 'Folder name', required: true }),
    help: command_1.flags.help({})
};
exports.default = dashboard;
//# sourceMappingURL=dashboard.js.map