"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const child = require("child_process");
const util = require("util");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class fields extends command_1.SfdxCommand {
    async run() {
        const exec = util.promisify(child.exec);
        this.ux.startSpinner('Getting fields of ' + this.flags.name);
        var result = await exec('sfdx force:schema:sobject:describe -s ' + this.flags.name + ' --json', { maxBuffer: 1024 * 500 });
        var newJson = JSON.parse(result.stdout);
        if (this.flags.custom) {
            for (var i in newJson.result.fields) {
                if (newJson.result.fields[i].custom) {
                    this.ux.stopSpinner();
                    console.log(newJson.result.fields[i].name);
                }
            }
        }
        else {
            for (var i in newJson.result.fields) {
                const isCustom = newJson.result.fields[i].custom ? 'custom' : 'standard';
                this.ux.stopSpinner();
                console.log(newJson.result.fields[i].name + ' ' + isCustom);
            }
        }
        return true;
    }
}
fields.description = 'Get fields from an object';
fields.args = [{ name: 'file' }];
fields.requiresUsername = true;
// Comment this out if your command does not support a hub org username
fields.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
fields.requiresProject = true;
fields.flagsConfig = {
    name: command_1.flags.string({ char: 'n', description: 'object name' }),
    custom: command_1.flags.boolean({ char: 'c', description: ' get custom fields' }),
    help: command_1.flags.help({})
};
exports.default = fields;
//# sourceMappingURL=fields.js.map