"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const child = require("child_process");
const util = require("util");
const fs = require("fs");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
class create extends command_1.SfdxCommand {
    async run() {
        const exec = util.promisify(child.exec);
        this.ux.startSpinner('Creating scratch org ' + this.flags.name + ' in progress ');
        const commandCreate = await exec('sfdx force:org:create -a ' + this.flags.name + ' -s -f config/project-scratch-def.json -w 10 -d 29 --json');
        let resultCreate = JSON.parse(commandCreate.stdout);
        this.ux.stopSpinner();
        this.ux.log(resultCreate.stdout);
        this.ux.startSpinner('Pushing sources in progress');
        const resultPush = await exec('sfdx force:source:push');
        this.ux.stopSpinner();
        this.ux.log(resultPush.stdout);
        if (this.flags.infos) {
            this.ux.startSpinner('Creating info file');
            var data = "Username : " + resultCreate.result.username + "\n";
            const commandPassword = await exec('sfdx force:user:password:generate --json');
            let resultPassword = JSON.parse(commandPassword.stdout);
            if (resultPassword.status == 0) {
                data = data + "Password : " + resultPassword.result.password;
            }
            await fs.writeFileSync('infosScratch.txt', data);
            this.ux.stopSpinner();
        }
        if (this.flags.open) {
            await exec('sfdx force:org:open');
        }
        ;
        return true;
    }
}
create.description = 'Create a scratch org and push automatically sources into it';
create.args = [{ name: 'file' }];
create.requiresUsername = false;
// Comment this out if your command does not support a hub org username
create.supportsDevhubUsername = false;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
create.requiresProject = true;
create.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    name: command_1.flags.string({ char: 'n', description: 'Scratch Org name', required: true }),
    open: command_1.flags.boolean({ char: 'o', description: 'Open scratch org after the sources push' }),
    infos: command_1.flags.boolean({ char: 'i', description: 'Create a text file at the root with username and password' }),
    help: command_1.flags.help({}),
};
exports.default = create;
//# sourceMappingURL=create.js.map