"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const child = require("child_process");
const util = require("util");
const fs = require("fs");
const path = require("path");
var utility = require('../../../scripts/utility.ts');
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class deploy extends command_1.SfdxCommand {
    async run() {
        const manifest_path = path.join(process.cwd(), this.flags.manifest);
        let classes_path = '';
        if (this.flags.testpath != null || this.flags.testpath != undefined) {
            classes_path = path.join(process.cwd(), this.flags.testpath);
        }
        else {
            classes_path = './force-app/main/default/classes';
        }
        let readManifest = fs.readFileSync(manifest_path);
        let queryTestClasses = '';
        await utility.promisesParser(readManifest).then(async function (result) {
            for (let type of result.Package.types) {
                if (type.name == 'ApexClass') {
                    if (type.members[0] === '*') {
                        let ext_file_list = utility.recFindByExt(classes_path, 'cls');
                        for (let file of ext_file_list) {
                            let readFile = fs.readFileSync(file);
                            if (readFile.includes('@isTest') || readFile.includes('@istest') || readFile.includes('@IsTest') || readFile.includes('@Istest')) {
                                queryTestClasses = queryTestClasses + path.basename(file, '.cls') + ',';
                            }
                        }
                    }
                    else {
                        for (let member of type.members) {
                            const path_file = path.join(classes_path, member + '.cls');
                            let readFile = fs.readFileSync(path_file);
                            if (readFile.includes('@isTest') || readFile.includes('@istest') || readFile.includes('@IsTest') || readFile.includes('@Istest')) {
                                queryTestClasses = queryTestClasses + member + ',';
                            }
                        }
                    }
                }
            }
        });
        queryTestClasses = queryTestClasses.substring(0, queryTestClasses.length - 1);
        console.log(queryTestClasses.split(',')[0] + ',' + queryTestClasses);
        const exec = util.promisify(child.exec);
        this.ux.startSpinner('Déploiement en cours');
        let query = 'sfdx force:source:deploy -l RunSpecifiedTests -r ' + queryTestClasses.split(',')[0] + ',' + queryTestClasses + ' -x ' + manifest_path;
        if (this.flags.check)
            query = query + ' -c';
        await exec(query);
        this.ux.stopSpinner('Déploiement fini');
        return true;
    }
}
deploy.description = '(Not finisehd yet) Deploy on production org with a manifest file';
deploy.args = [{ name: 'file' }];
deploy.requiresUsername = true;
// Comment this out if your command does not support a hub org username
deploy.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
deploy.requiresProject = true;
deploy.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    manifest: command_1.flags.string({ char: 'x', description: 'Manifest file to deploy', required: true }),
    check: command_1.flags.boolean({ char: 'c', description: 'Check' }),
    testpath: command_1.flags.string({ char: 'p', description: 'Test classes path' }),
    help: command_1.flags.help({}),
};
exports.default = deploy;
//# sourceMappingURL=deploy.js.map